==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/SubmissionResponseConfigInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SubmissionResponseConfigInner
 */
@JsonPropertyOrder({ SubmissionResponseConfigInner.JSON_PROPERTY_LABEL,
        SubmissionResponseConfigInner.JSON_PROPERTY_NAME })
@JsonTypeName("SubmissionResponse_config_inner")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SubmissionResponseConfigInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public SubmissionResponseConfigInner() {
    }

    public SubmissionResponseConfigInner label(String label) {

        this.label = label;
        return this;
    }

    /**
     * Display name of the variable in the Admin Console
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "Subdomain", value = "Display name of the variable in the Admin Console")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLabel(String label) {
        this.label = label;
    }

    public SubmissionResponseConfigInner name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Name of the variable
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "subdomain", value = "Name of the variable")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SubmissionResponseConfigInner submissionResponseConfigInner = (SubmissionResponseConfigInner) o;
        return Objects.equals(this.label, submissionResponseConfigInner.label)
                && Objects.equals(this.name, submissionResponseConfigInner.name);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(label, name);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SubmissionResponseConfigInner {\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/SubmissionResponseConfigInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SubmissionResponseConfigInner
 */
@JsonPropertyOrder({ SubmissionResponseConfigInner.JSON_PROPERTY_LABEL,
        SubmissionResponseConfigInner.JSON_PROPERTY_NAME })
@JsonTypeName("SubmissionResponse_config_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class SubmissionResponseConfigInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public SubmissionResponseConfigInner() {
    }

    public SubmissionResponseConfigInner label(String label) {

        this.label = label;
        return this;
    }

    /**
     * Display name of the variable in the Admin Console
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "Subdomain", value = "Display name of the variable in the Admin Console")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLabel(String label) {
        this.label = label;
    }

    public SubmissionResponseConfigInner name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Name of the variable
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "subdomain", value = "Name of the variable")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SubmissionResponseConfigInner submissionResponseConfigInner = (SubmissionResponseConfigInner) o;
        return Objects.equals(this.label, submissionResponseConfigInner.label)
                && Objects.equals(this.name, submissionResponseConfigInner.name);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(label, name);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SubmissionResponseConfigInner {\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
